@@ -16,3 +16,8 @@ class TestEval(unittest.TestCase):
         result = os.system(
             'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric emf1 --print --beamsearch --outfile')
         print(result)
+
+    def testEvalClassify(self):
+        result = os.system(
+            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/classification.csv --metric classification --print')
+        print(result)
